@@ -1,8 +1,12 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 import copy as cp
+import os
 import os.path as osp
+import time
 
+import numpy as np
 import torch
+import torch.distributed as dist
 from mmcv.parallel import MMDataParallel, MMDistributedDataParallel
 from mmcv.runner import (DistSamplerSeedHook, EpochBasedRunner, OptimizerHook,
                          build_optimizer, get_dist_info)
@@ -15,6 +19,42 @@ from ..utils import PreciseBNHook, get_root_logger
 from .test import multi_gpu_test
 
 
+def init_random_seed(seed=None, device='cuda', distributed=True):
+    """Initialize random seed.
+
+    If the seed is not set, the seed will be automatically randomized,
+    and then broadcast to all processes to prevent some potential bugs.
+    Args:
+        seed (int, Optional): The seed. Default to None.
+        device (str): The device where the seed will be put on.
+            Default to 'cuda'.
+        distributed (bool): Whether to use distributed training.
+            Default: True.
+    Returns:
+        int: Seed to be used.
+    """
+    if seed is not None:
+        return seed
+
+    # Make sure all ranks share the same random seed to prevent
+    # some potential bugs. Please refer to
+    # https://github.com/open-mmlab/mmdetection/issues/6339
+    rank, world_size = get_dist_info()
+    seed = np.random.randint(2**31)
+
+    if world_size == 1:
+        return seed
+
+    if rank == 0:
+        random_num = torch.tensor(seed, dtype=torch.int32, device=device)
+    else:
+        random_num = torch.tensor(0, dtype=torch.int32, device=device)
+
+    if distributed:
+        dist.broadcast(random_num, src=0)
+    return random_num.item()
+
+
 def train_model(model,
                 dataset,
                 cfg,
@@ -88,8 +128,7 @@ def train_model(model,
             broadcast_buffers=False,
             find_unused_parameters=find_unused_parameters)
     else:
-        model = MMDataParallel(
-            model.cuda(cfg.gpu_ids[0]), device_ids=cfg.gpu_ids)
+        model = MMDataParallel(model, device_ids=cfg.gpu_ids)
 
     # build runner
     optimizer = build_optimizer(model, cfg.optimizer)
@@ -118,11 +157,21 @@ def train_model(model,
     runner.register_training_hooks(cfg.lr_config, optimizer_config,
                                    cfg.checkpoint_config, cfg.log_config,
                                    cfg.get('momentum_config', None))
-    if distributed:
-        if cfg.omnisource:
-            runner.register_hook(OmniSourceDistSamplerSeedHook())
-        else:
-            runner.register_hook(DistSamplerSeedHook())
+
+    # multigrid setting
+    multigrid_cfg = cfg.get('multigrid', None)
+    if multigrid_cfg is not None:
+        from mmaction.utils.multigrid import LongShortCycleHook
+        multigrid_scheduler = LongShortCycleHook(cfg)
+        runner.register_hook(multigrid_scheduler)
+        logger.info('Finish register multigrid hook')
+
+        # subbn3d aggregation is HIGH, as it should be done before
+        # saving and evaluation
+        from mmaction.utils.multigrid import SubBatchNorm3dAggregationHook
+        subbn3d_aggre_hook = SubBatchNorm3dAggregationHook()
+        runner.register_hook(subbn3d_aggre_hook, priority='VERY_HIGH')
+        logger.info('Finish register subbn3daggre hook')
 
     # precise bn setting
     if cfg.get('precise_bn', False):
@@ -138,7 +187,14 @@ def train_model(model,
                                                   **dataloader_setting)
         precise_bn_hook = PreciseBNHook(data_loader_precise_bn,
                                         **cfg.get('precise_bn'))
-        runner.register_hook(precise_bn_hook)
+        runner.register_hook(precise_bn_hook, priority='HIGHEST')
+        logger.info('Finish register precisebn hook')
+
+    if distributed:
+        if cfg.omnisource:
+            runner.register_hook(OmniSourceDistSamplerSeedHook())
+        else:
+            runner.register_hook(DistSamplerSeedHook())
 
     if validate:
         eval_cfg = cfg.get('evaluation', {})
@@ -167,24 +223,29 @@ def train_model(model,
         runner_kwargs = dict(train_ratio=train_ratio)
     runner.run(data_loaders, cfg.workflow, cfg.total_epochs, **runner_kwargs)
 
+    if distributed:
+        dist.barrier()
+    time.sleep(5)
+
     if test['test_last'] or test['test_best']:
         best_ckpt_path = None
         if test['test_best']:
-            if hasattr(eval_hook, 'best_ckpt_path'):
-                best_ckpt_path = eval_hook.best_ckpt_path
-
-            if best_ckpt_path is None or not osp.exists(best_ckpt_path):
+            ckpt_paths = [x for x in os.listdir(cfg.work_dir) if 'best' in x]
+            ckpt_paths = [x for x in ckpt_paths if x.endswith('.pth')]
+            if len(ckpt_paths) == 0:
+                runner.logger.info('Warning: test_best set, but no ckpt found')
                 test['test_best'] = False
-                if best_ckpt_path is None:
-                    runner.logger.info('Warning: test_best set as True, but '
-                                       'is not applicable '
-                                       '(eval_hook.best_ckpt_path is None)')
-                else:
-                    runner.logger.info('Warning: test_best set as True, but '
-                                       'is not applicable (best_ckpt '
-                                       f'{best_ckpt_path} not found)')
                 if not test['test_last']:
                     return
+            elif len(ckpt_paths) > 1:
+                epoch_ids = [
+                    int(x.split('epoch_')[-1][:-4]) for x in ckpt_paths
+                ]
+                best_ckpt_path = ckpt_paths[np.argmax(epoch_ids)]
+            else:
+                best_ckpt_path = ckpt_paths[0]
+            if best_ckpt_path:
+                best_ckpt_path = osp.join(cfg.work_dir, best_ckpt_path)
 
         test_dataset = build_dataset(cfg.data.test, dict(test_mode=True))
         gpu_collect = cfg.get('evaluation', {}).get('gpu_collect', False)
@@ -207,7 +268,7 @@ def train_model(model,
         if test['test_last']:
             names.append('last')
             ckpts.append(None)
-        if test['test_best']:
+        if test['test_best'] and best_ckpt_path is not None:
             names.append('best')
             ckpts.append(best_ckpt_path)
 
